* DerogationReplication.do

*
* Replication Data for
* "Emergency and Escape: Explaining Derogations from Human Rights Treaties" 
* Authors: Emilie M. Hafner-Burton, Larry R. Helfer, and Christopher J. Fariss 
*
* to use this replication file you need to install the btscs ado file available here:
*http://www.prio.no/CSCW/Datasets/Stata-Tools/
* and the outtex ado file which can be installed within stata with the following command:
* findit outtex
*

* clear Stata workspace 
clear

* load data
use "DerogationAppedixReplication.dta"

* create splines
btscs y year ccode, g(y_count) nspline(3)
rename _spline1 y_spline1
rename _spline2 y_spline2
rename _spline3 y_spline3

generate soe = id2
btscs soe year ccode, g(soe_count) nspline(3)
generate soe_count2 = soe_count*soe_count
generate soe_count3 = soe_count*soe_count*soe_count
rename _spline1 soe_spline1
rename _spline2 soe_spline2
rename _spline3 soe_spline3

* generate additional variables for analysis
generate t2 =t1*t1
generate t3 =t1*t1*t1
generate lpop =ln(populationvalues) 
generate lcapita =ln(realpercapitaincomevalues) 

* Appendix Table 5
logit y stabledemocracy courtexec civtot lpop lcapita t1 t2 t3 if id1==1 & id2==1, robust cluster(ccode)
outtex, below labels level legend

* set panel id variables
xtset ccode year

* Appendix Table 6
xtgee y stabledemocracy courtexec civtot lpop lcapita t1 t2 t3 if id1==1 & id2==1, family(binomial 1) link(logit) corr(independent) robust
outtex, below labels level legend

* Appendix Table 7
heckprob y stabledemocracy courtexec civtot lpop lcapita t1 t2 t3 if id1==1, select(id2= stabledemocracy courtexec  civtot lpop lcapita soe_count soe_count2 soe_count3 )
outtex, below labels level legend

* Appendix Table 8
heckprob y stabledemocracy courtexec civtot lpop lcapita t1 t2 t3 if id1==1, select(id2=  civtot lpop lcapita soe_count soe_count2 soe_count3 )
outtex, below labels level legend

* Appendix Table 9
heckman proptime proptime_lag1 stabledemocracy courtexec treatyratavg civtot lpop lcapita if id2==1, select(y = stabledemocracy courtexec  civtot lpop lcapita t1 t2 t3 )
outtex, below labels level legend

* Appendix Table 10 
heckman proprights proprights_lag1 stabledemocracy courtexec treatyratavg civtot lpop lcapita if id2==1, select(y = stabledemocracy courtexec  civtot lpop lcapita t1 t2 t3 )
outtex, below labels level legend

* Appendix Table 21 (this model takes a long time to converge)
xtgee total total_lag1 stabledemocracy courtexec civtot lpop lcapita, family(nbinomial) link(nbinomial) corr(independent) vce(robust)
outtex, below labels level legend
